@@ -30,11 +30,11 @@ class ScalingConfig : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ScalingConfig(const KScreen::OutputList &outputList, QWidget* parent = 0);
-    virtual ~ScalingConfig();
+    explicit ScalingConfig(const KScreen::OutputList &outputList, QWidget* parent = nullptr);
+    ~ScalingConfig() override;
     
 protected:
-    void accept() Q_DECL_OVERRIDE;
+    void accept() override;
 private:
     void load();
     qreal scaleFactor() const;
